<?php

/**
 * @file
 * Contains the configuration form for Error Log.
 */

/**
 * Adds Error Log settings form to form.
 *
 * @param array $form
 *   The form definition.
 * @param array $form_state
 *   The form state.
 */
function error_log_settings_form(array &$form, array &$form_state) {
  $form['error_log'] = array(
    '#type' => 'fieldset',
    '#title' => t('Error Log'),
    '#collapsible' => TRUE,
  );
  foreach (watchdog_severity_levels() as $level => $label) {
    $watchdog_levels["level_$level"] = $label;
  }
  $form['error_log']['error_log_levels'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Message levels'),
    '#description' => t('Check the log levels which should be sent to the PHP error log.'),
    '#default_value' => variable_get('error_log_levels', error_log_default_levels()),
    '#options' => $watchdog_levels,
  );
  $form['error_log']['error_log_ignored_types'] = array(
    '#type' => 'textarea',
    '#title' => t('Ignored types'),
    '#description' => t('A list of log event types for which messages should not be sent to the PHP error log (one type per line). Commonly-configured types include <em>access denied</em> for 403 errors and <em>page not found</em> for 404 errors.'),
    '#default_value' => variable_get('error_log_ignored_types', ''),
  );
  $form['error_log']['error_log_format'] = array(
    '#type' => 'textfield',
    '#title' => t('Log format'),
    '#default_value' => variable_get('error_log_format', '[!level] [!type] [!ip] [uid:!uid] [!request_uri] [!referer] !message'),
    '#description' => t('Specify the format of the log entry. Available variables are: !variables', array('!variables' => error_log_format_variables())),
    '#maxlength' => 280,
  );
}

/**
 * Renders a description of log format variables.
 *
 * @return string
 *   The description HTML.
 */
function error_log_format_variables() {
  $variables = array(
    '!base_url' => t('Base URL of the site.'),
    '!ip' => t('IP address of the user triggering the message.'),
    '!level' => t('The severity level of the event as an untranslated string; ranges from emergency to debug.'),
    '!link' => t('A link to associate with the message.'),
    '!message' => t('The message to store in the log.'),
    '!referer' => t('HTTP Referer if available.'),
    '!request_uri' => t('The requested URI.'),
    '!severity' => t('The severity level of the event as an integer; ranges from 0 (Emergency) to 7 (Debug).'),
    '!timestamp' => t('Unix timestamp of the log entry.'),
    '!type' => t('The category to which this message belongs.'),
    '!uid' => t('User ID.'),
  );
  $output = '<dl>';
  foreach ($variables as $variable => $description) {
    $output .= "<dt><code>$variable</code></dt><dd>$description</dd>";
  }
  return $output . '</dl>';
}
